import { ActiveHashRecord, EagerQueryable } from "activehashie";
import { ModelValidationErrorReports } from "./model_validation_error_report";
export interface ValidatesMethods {
    presence: ValidatesMethod.Params.Presence;
    presenceBelongsTo: ValidatesMethod.Params.Presence;
    uniqueness: ValidatesMethod.Params.Uniqueness;
    length: ValidatesMethod.Params.Length;
    format: ValidatesMethod.Params.Format;
    numericality: ValidatesMethod.Params.Numericality;
    inclusion: ValidatesMethod.Params.Inclusion;
    exclusion: ValidatesMethod.Params.Exclusion;
}
export declare namespace ValidatesMethod {
    namespace Params {
        type Presence = true;
        type Uniqueness = true;
        type Length = {
            minimum?: number;
            maximum?: number;
            is?: number;
        };
        type Format = {
            with?: RegExp;
            without?: RegExp;
        };
        type Numericality = true | {
            only_integer?: boolean;
            greater_than?: number;
            greater_than_or_equal_to?: number;
            equal_to?: number;
            less_than?: number;
            less_than_or_equal_to?: number;
        };
        type Inclusion = {
            in: any[];
        };
        type Exclusion = {
            in: any[];
        };
    }
    namespace Method {
        function presence<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, _: ValidatesMethod.Params.Presence, model: EagerQueryable<Record>, column: keyof Record): void;
        function presenceBelongsTo<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, _: ValidatesMethod.Params.Presence, model: EagerQueryable<Record>, column: keyof Record): void;
        function uniqueness<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, _: ValidatesMethod.Params.Uniqueness, model: EagerQueryable<Record>, column: keyof Record): void;
        function length<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Length, model: EagerQueryable<Record>, column: keyof Record): void;
        function format<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Format, model: EagerQueryable<Record>, column: keyof Record): void;
        function numericality<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Numericality, model: EagerQueryable<Record>, column: keyof Record): void;
        function inclusion<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Inclusion, model: EagerQueryable<Record>, column: keyof Record): void;
        function exclusion<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Exclusion, model: EagerQueryable<Record>, column: keyof Record): void;
    }
}
